import type { Application as ExpressApp } from 'express';
import type { LwrProxyConfiguration } from './proxy-server.js';
/**
 * Proxy middleware for handling requests that are served by the LWR server or lambda.
 *
 * @param app - The Express app instance to which the middleware is attached.
 * @param defaultHost - A URL string pointing to the local proxy server for handling requests.
 * @param remoteOrigin - A URL string representing the value of the first entry in the `_proxy` configuration file.
 */
export declare function addLocalProxyMiddleware(app: ExpressApp, defaultHost: string, remoteOrigin?: string): void;
/**
 * Middleware to handle API request proxying to a configured remote origin.
 *
 * This middleware forwards API requests to the specified remote origin
 * as defined in the proxy configuration.
 *
 * @param app - The Express app instance to which the middleware is attached.
 * @param proxyConfig - Configuration details initialized when the proxy server starts.
 */
export declare function addRemoteProxyMiddleware(app: ExpressApp, proxyConfig: LwrProxyConfiguration): void;
//# sourceMappingURL=middleware.d.ts.map